// Copyright 2023 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

syntax = "proto3";

package google.ads.googleads.v14.resources;

import "google/api/field_behavior.proto";
import "google/api/resource.proto";

option csharp_namespace = "Google.Ads.GoogleAds.V14.Resources";
option go_package = "google.golang.org/genproto/googleapis/ads/googleads/v14/resources;resources";
option java_multiple_files = true;
option java_outer_classname = "LandingPageViewProto";
option java_package = "com.google.ads.googleads.v14.resources";
option objc_class_prefix = "GAA";
option php_namespace = "Google\\Ads\\GoogleAds\\V14\\Resources";
option ruby_package = "Google::Ads::GoogleAds::V14::Resources";

// Proto file describing the landing page view resource.

// A landing page view with metrics aggregated at the unexpanded final URL
// level.
message LandingPageView {
  option (google.api.resource) = {
    type: "googleads.googleapis.com/LandingPageView"
    pattern: "customers/{customer_id}/landingPageViews/{unexpanded_final_url_fingerprint}"
  };

  // Output only. The resource name of the landing page view.
  // Landing page view resource names have the form:
  //
  // `customers/{customer_id}/landingPageViews/{unexpanded_final_url_fingerprint}`
  string resource_name = 1 [
    (google.api.field_behavior) = OUTPUT_ONLY,
    (google.api.resource_reference) = {
      type: "googleads.googleapis.com/LandingPageView"
    }
  ];

  // Output only. The advertiser-specified final URL.
  optional string unexpanded_final_url = 3
      [(google.api.field_behavior) = OUTPUT_ONLY];
}
